"""
# Welcome to your CDK TypeScript Construct Library project!

You should explore the contents of this project. It demonstrates a CDK Construct Library that includes a construct (`S3LambdaS3`)
which contains an Amazon SQS queue that is subscribed to an Amazon SNS topic.

The construct defines an interface (`S3LambdaS3Props`) to configure the visibility timeout of the queue.

## Useful commands

* `npm run build`   compile typescript to js
* `npm run watch`   watch for changes and compile
* `npm run test`    perform the jest unit tests
"""
import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

from ._jsii import *

import aws_cdk.aws_lambda
import aws_cdk.core


class S3LambdaS3(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="s3-lambda-s3.S3LambdaS3"):
    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, code: aws_cdk.aws_lambda.Code, handler: str) -> None:
        """
        :param scope: -
        :param id: -
        :param code: -
        :param handler: -
        """
        props = S3LambdaS3Props(code=code, handler=handler)

        jsii.create(S3LambdaS3, self, [scope, id, props])


@jsii.data_type(jsii_type="s3-lambda-s3.S3LambdaS3Props", jsii_struct_bases=[], name_mapping={'code': 'code', 'handler': 'handler'})
class S3LambdaS3Props():
    def __init__(self, *, code: aws_cdk.aws_lambda.Code, handler: str) -> None:
        """
        :param code: -
        :param handler: -
        """
        self._values = {
            'code': code,
            'handler': handler,
        }

    @builtins.property
    def code(self) -> aws_cdk.aws_lambda.Code:
        return self._values.get('code')

    @builtins.property
    def handler(self) -> str:
        return self._values.get('handler')

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return 'S3LambdaS3Props(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())


__all__ = [
    "S3LambdaS3",
    "S3LambdaS3Props",
]

publication.publish()
